==> haskell-logict-0.7.1.0-130-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logict
version:              0.7.1.0
visibility:           public
id:                   logict-0.7.1.0-LI6Pv3UGJS6EXWula0ljkB
key:                  logict-0.7.1.0-LI6Pv3UGJS6EXWula0ljkB
license:              BSD-3-Clause
copyright:
    (c) 2007-2014 Dan Doel,
    (c) 2011-2013 Edward Kmett,
    (c) 2014      Roman Cheplyaka,
    (c) 2020-2021 Andrew Lelechenko,
    (c) 2020-2021 Kevin Quick

maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Dan Doel
homepage:             https://github.com/Bodigrim/logict#readme
synopsis:             A backtracking logic-programming monad.
description:
    Adapted from the paper
    <http://okmij.org/ftp/papers/LogicT.pdf Backtracking, Interleaving, and Terminating Monad Transformers>
    by Oleg Kiselyov, Chung-chieh Shan, Daniel P. Friedman, Amr Sabry.

category:             Control
abi:                  ba1e379a0e505a2089f6e7a702e6d8d9
exposed:              True
exposed-modules:      Control.Monad.Logic Control.Monad.Logic.Class
import-dirs:          /usr/lib/ghc-9.0.2/site-local/logict-0.7.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/logict-0.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logict
hs-libraries:         HSlogict-0.7.1.0-LI6Pv3UGJS6EXWula0ljkB
depends:              base-4.15.1.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html:         /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-logict-0.7.1.0-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-logict.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 logict
version:              0.7.1.0
visibility:           public
id:                   logict-0.7.1.0-CqLwLG8ULk78kDom1dQfGS
key:                  logict-0.7.1.0-CqLwLG8ULk78kDom1dQfGS
license:              BSD-3-Clause
copyright:
    (c) 2007-2014 Dan Doel,
    (c) 2011-2013 Edward Kmett,
    (c) 2014      Roman Cheplyaka,
    (c) 2020-2021 Andrew Lelechenko,
    (c) 2020-2021 Kevin Quick

maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Dan Doel
homepage:             https://github.com/Bodigrim/logict#readme
synopsis:             A backtracking logic-programming monad.
description:
    Adapted from the paper
    <http://okmij.org/ftp/papers/LogicT.pdf Backtracking, Interleaving, and Terminating Monad Transformers>
    by Oleg Kiselyov, Chung-chieh Shan, Daniel P. Friedman, Amr Sabry.

category:             Control
abi:                  81b90fff0cb865413d27f08725e174d1
exposed:              True
exposed-modules:      Control.Monad.Logic Control.Monad.Logic.Class
import-dirs:          /usr/lib/ghc-9.0.2/site-local/logict-0.7.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/logict-0.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-logict
hs-libraries:         HSlogict-0.7.1.0-CqLwLG8ULk78kDom1dQfGS
depends:              base-4.15.1.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-logict/html/logict.haddock
haddock-html:         /usr/share/doc/haskell-logict/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
